@@ -28,6 +28,7 @@
 #include <KCursor>
 #include <KDebug>
 #include <KFileDialog>      //::open()
+#include <KInputDialog>
 #include <KGlobalSettings> //::timerEvent()
 #include <KIO/NetAccess>
 #include <KLocale>
@@ -100,6 +101,7 @@ MainWindow::MainWindow()
         , m_stopScreenSaver( 0 )
         , m_stopSleepCookie( -1 )
         , m_stopScreenPowerMgmtCookie( -1 )
+        , m_profileMaxDays(30)
         , m_toolbarIsHidden(false)
         , m_statusbarIsHidden(false)
         , m_menuBarIsHidden(false)
@@ -204,10 +206,11 @@ MainWindow::init()
     //connect the stuff in loadView
     connect( m_loadView, SIGNAL(openDVDPressed()), this, SLOT(playDisc()) );
     connect( m_loadView, SIGNAL(openFilePressed()), this, SLOT(openFileDialog()) );
+    connect( m_loadView, SIGNAL(openStreamPressed()), this, SLOT(openStreamDialog()) );
     connect( m_loadView, SIGNAL(loadUrl(KUrl)), this, SLOT(open(KUrl)) );
 
     //connect the video player
-    connect( engine(), SIGNAL(stateUpdated(Phonon::State,Phonon::State)), this, SLOT(engineStateChanged(Phonon::State,Phonon::State)) );
+    connect( engine(), SIGNAL(stateUpdated(Phonon::State,Phonon::State)), this, SLOT(engineStateChanged(Phonon::State)) );
     connect( engine(), SIGNAL(currentSourceChanged(Phonon::MediaSource)), this, SLOT(engineMediaChanged(Phonon::MediaSource)) );
     connect( engine(), SIGNAL(seekableChanged(bool)), this, SLOT(engineSeekableChanged(bool)) );
     connect( engine(), SIGNAL(metaDataChanged()), this, SLOT(engineMetaDataChanged()) );
@@ -534,7 +537,7 @@ MainWindow::open( const KUrl &url )
     kDebug() << url;
 
     if( load( url ) ) {
-        const int offset = TheStream::hasProfile()
+        const int offset = (TheStream::hasProfile() && isFresh())
                 // adjust offset if we have session history for this video
                 ? TheStream::profile().readEntry<int>( "Position", 0 )
                 : 0;
@@ -587,7 +590,7 @@ MainWindow::load( const KUrl &url )
 
     //let xine handle invalid, etc, KUrlS
     //TODO it handles non-existing files with bad error message
-    bool ret = engine()->load( url );
+    const bool ret = engine()->load( url );
     if( ret )
     {
         if( TheStream::hasVideo() )
@@ -637,10 +640,20 @@ MainWindow::openFileDialog()
     mimeFilter << QLatin1String( "video/mp4" );
     mimeFilter << QLatin1String( "application/x-cd-image" ); // added for *.iso images
 
-    const KUrl url =
-            KFileDialog::getOpenUrl(KGlobalSettings::videosPath(),
-                                    mimeFilter.join(QLatin1String(" ")),
-                                    this, i18n("Select File to Play") );
+    static KUrl lastDirectory;
+
+    KFileDialog dlg( KGlobalSettings::videosPath(), mimeFilter.join(QLatin1String( " " ) ), this );
+    dlg.setCaption( i18n("Select File to Play") );
+    dlg.setOperationMode( KFileDialog::Opening );
+
+    if( !lastDirectory.isEmpty() )
+        dlg.setUrl( lastDirectory );
+
+    dlg.exec();
+
+    lastDirectory = dlg.baseUrl();
+    const KUrl url = dlg.selectedFile();
+
     if( url.isEmpty() )
     {
         kDebug() << "URL empty in MainWindow::playDialogResult()";
@@ -652,6 +665,22 @@ MainWindow::openFileDialog()
     }
 }
 
+void
+MainWindow::openStreamDialog()
+{
+    KUrl url(KInputDialog::getText( i18nc("@title:window", "Stream to Play"), i18n("Stream:") ));
+
+    if( url.isEmpty() )
+    {
+        kDebug() << "URL empty in MainWindow::openStreamDialog()";
+        return;
+    }
+    else
+    {
+        open( url );
+    }
+}
+
 void
 MainWindow::playDisc()
 {
@@ -939,6 +968,13 @@ action( const char *name )
     return action;
 }
 
+bool MainWindow::isFresh()
+{
+    QDate date = QDate::fromString(TheStream::profile().readEntry<QString>( "Date", QDate::currentDate().toString("dd/MM/yyyy") ), "dd/MM/yyyy");
+
+    return (date.daysTo(QDate::currentDate()) < m_profileMaxDays) ? true : false;
+}
+
 
 } //namespace Dragon
 
